# ncmpy

ncmpy is a curses [mpd][] client;

ncmpy features:

-   playback control;

-   queue control;

-   song rating;

-   database control;

-   auto lyrics fetching and saving;

-   lyrics highlighting;

-   artist-album view;

-   search by tags;

-   output control;

## install

install using pip:

    pip install ncmpy

## usage

ncmpy provides a curses interface; so you can run it interactively:

    ncmpy

## config

-   system config file: `/etc/ncmpy/ncmpy.conf`;

-   user config file: `~/.config/ncmpy/ncmpy.conf`;

a config file sample is provided: `data/ncmpy.conf.example`;

## license

Copyright (c) 2011-2018 Cyker Way

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <https://www.gnu.org/licenses/>.

[mpd]: http://musicpd.org/

